@@ -17,6 +17,7 @@ import testflows.settings as settings
 from testflows._core.flags import Flags, SKIP
 from testflows._core.cli.colors import color
 from testflows._core.message import Message
+from testflows._core.testtype import TestType
 
 width = 70
 count = 0
@@ -65,6 +66,9 @@ def format_result(msg):
     if flags & SKIP and settings.show_skipped is False:
         return
 
+    if getattr(TestType, msg["test_type"]) < TestType.Iteration:
+        return
+
     count += 1
     _result = f"{color_result(msg['result_type'])}"
     # wrap if we hit max width
