@@ -16,7 +16,7 @@ import textwrap
 import functools
 import testflows.settings as settings
 
-from testflows._core.flags import Flags, SKIP
+from testflows._core.flags import Flags, SKIP, LAST_RETRY
 from testflows._core.testtype import TestType, TestSubType
 from testflows._core.message import Message
 from testflows._core.objects import ExamplesTable
@@ -39,7 +39,7 @@ def color_secondary_keyword(keyword, no_colors=False):
 def color_test_name(name, no_colors=False):
     return color(name, "white", attrs=[], no_colors=no_colors)
 
-def color_result(result, attrs=None, no_colors=False):
+def color_result(result, attrs=None, no_colors=False, retry=False):
     if attrs is None:
         attrs = ["bold"]
     if result.startswith("X"):
@@ -48,6 +48,8 @@ def color_result(result, attrs=None, no_colors=False):
         return functools.partial(color, color="green", attrs=attrs, no_colors=no_colors)
     elif result == "Skip":
         return functools.partial(color, color="cyan", attrs=attrs, no_colors=no_colors)
+    elif retry:
+        return functools.partial(color, color="cyan", attrs=attrs, no_colors=no_colors)
     elif result == "Error":
         return functools.partial(color, color="yellow", attrs=attrs, no_colors=no_colors)
     elif result == "Fail":
@@ -196,6 +198,8 @@ def format_test(msg, keyword, no_colors=False):
             keyword += "Suite"
     elif test_type == TestType.Iteration:
         keyword += "Iteration"
+    elif test_type == TestType.RetryIteration:
+        keyword += "Retry"
     elif test_type == TestType.Step:
         keyword += "Step"
     elif test_type == TestType.Outline:
@@ -228,8 +232,8 @@ def format_test(msg, keyword, no_colors=False):
 
 def format_result(msg, no_colors=False):
     result = msg["result_type"]
-
-    _color = color_result(result, no_colors=no_colors)
+    _retry = get_type(msg) == TestType.RetryIteration and LAST_RETRY not in Flags(msg["test_flags"])
+    _color = color_result(result, no_colors=no_colors, retry=_retry)
     _result = _color(result, no_colors=no_colors)
     _test = color_test_name(msg["result_test"], no_colors=no_colors)
 
@@ -266,7 +270,7 @@ formatters = {
 }
 
 def transform(no_colors=False, show_input=True):
-    """Transform parsed log line into a short format.
+    """Transform parsed log line into a flat format.
     """
     line = None
     while True:
