@@ -12,4 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from testflows._core.parallel import Context, ContextVar, copy_context, Pool
+from testflows._core.parallel import Context, ContextVar, copy_context
+from testflows._core.parallel.executor.thread import ThreadPoolExecutor as Pool, ThreadPoolExecutor as ThreadPool
+from testflows._core.parallel.executor.asyncio import AsyncPoolExecutor as AsyncPool
